//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithoutGot](index.md)/[advanceNum](advance-num.md)

# advanceNum

[common]\

@EncodeDefault

val [advanceNum](advance-num.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) = 0

进张数
